'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = function (context) {
  var _context$output = context.output,
      output = _context$output === undefined ? {} : _context$output,
      imagePrefix = context.imagePrefix,
      fontPrefix = context.fontPrefix,
      isDev = context.isDev,
      strict = context.strict;

  var urlLoaderOptions = {
    limit: 2500
  };
  if (!isDev) {
    urlLoaderOptions = _extends({}, urlLoaderOptions, {
      publicPath: function publicPath(url) {
        var prefix = '';
        if (/\.(jpg|jpeg|png|bmp|gif)$/.test(url)) {
          prefix = imagePrefix;
        } else if (/\.(ttf|eot|svg|otf|woff(2)?)(\?v=[0-9]\.[0-9]\.[0-9])?$/.test(url)) {
          prefix = fontPrefix;
        }
        return typeof prefix === 'function' ? prefix(url) : _path2.default.posix.join(prefix, _path2.default.basename(url));
      },
      hash: 'sha512',
      digest: 'hex',
      name: '[hash:8].[ext]'
    });
  }

  var vueLoaderOptions = {
    postcss: {
      plugins: (0, _lib.postcssOptions)(context).plugins,
      options: { sourceMap: 'inline' }
    },
    loaders: {
      css: (0, _lib.vueStyleLoaders)(context),
      less: (0, _lib.vueStyleLoaders)(context, 'less'),
      stylus: (0, _lib.vueStyleLoaders)(context, 'stylus'),
      scss: (0, _lib.vueStyleLoaders)(context, {
        loader: 'sass-loader',
        options: { sourceMap: true }
      }),
      sass: (0, _lib.vueStyleLoaders)(context, {
        loader: 'sass-loader',
        options: { indentedSyntax: true, sourceMap: true }
      })
    }
  };

  var loaders = [{
    test: /\.(tpl|html)/,
    exclude: [nodeModulesDir],
    loader: require.resolve('html-loader')
  }, {
    test: /\.vue/,
    exclude: [nodeModulesDir],
    loader: 'vue-loader',
    options: vueLoaderOptions
  }, {
    test: /\.(es6|js|jsx)$/,
    exclude: /node_modules/,
    // exclude: [nodeModulesDir],
    loader: require.resolve('happypack/loader'),
    options: { id: 'js' }
  }, {
    test: /\.less/,
    exclude: [nodeModulesDir],
    use: (0, _lib.cssLoaders)(context, 'less')
  }, {
    test: /\.scss/,
    exclude: [nodeModulesDir],
    use: (0, _lib.cssLoaders)(context, {
      loader: 'sass-loader',
      options: { sourceMap: true }
    })
  }, {
    test: /\.styl/,
    exclude: [nodeModulesDir],
    use: (0, _lib.cssLoaders)(context, 'stylus')
  }, {
    test: /\.css/,
    use: (0, _lib.cssLoaders)(context)
  }, {
    test: /\.(png|jpg|jpeg|gif|bmp)$/,
    exclude: [nodeModulesDir],
    loader: require.resolve('url-loader'),
    options: isDev ? urlLoaderOptions : _extends({}, urlLoaderOptions, {
      outputPath: output.imagePath
    })
  }, {
    test: /\.woff(2)?(\?v=[0-9]\.[0-9]\.[0-9])?$/,
    loader: require.resolve('url-loader'),
    options: isDev ? urlLoaderOptions : _extends({}, urlLoaderOptions, {
      outputPath: output.fontPath,
      mimetype: 'application/font-woff'
    })
  }, {
    test: /\.(ttf|eot|svg|otf)(\?v=[0-9]\.[0-9]\.[0-9])?$/,
    loader: require.resolve('url-loader'),
    options: isDev ? urlLoaderOptions : _extends({}, urlLoaderOptions, {
      outputPath: output.fontPath
    })
  }];

  if (strict) {
    loaders.unshift({
      test: /\.(js|jsx|vue)$/,
      exclude: /node_modules/,
      enforce: 'pre',
      loader: 'eslint-loader',
      options: {
        cache: true
      }
    });
  }
  return loaders;
};

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _lib = require('./lib');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nodeModulesDir = _path2.default.resolve('node_modules');